@@ -150,7 +150,7 @@ class Storage(base.Storage):
         bucket = self.getBucket(bucketOrBucketName)
         ignores = ignores or self.DEFAULT_IGNORE_KEYWORDS
         delimiter = delimiter or self.delimiter
-        path = path or self.getPathInTempStore(key)
+        path = os.path.abspath(path) if path else self.getPathInTempStore(key)
         url = self.storageUrl(key, bucketOrBucketName=bucket)
 
         if not quiet:
@@ -211,7 +211,7 @@ class Storage(base.Storage):
     ):
         bucket = self.getBucket(bucketOrBucketName)
         ignores = ignores or self.DEFAULT_IGNORE_KEYWORDS
-        path = path or self.getPathInTempStore(key)
+        path = os.path.abspath(path) if path else self.getPathInTempStore(key)
         url = self.storageUrl(key, bucketOrBucketName=bucket)
         fileSize = self.getStorageSize(key, bucketOrBucketName=bucket)
 
@@ -283,7 +283,7 @@ class Storage(base.Storage):
     ):
         bucket = self.getBucket(bucketOrBucketName)
         ignores = ignores or self.DEFAULT_IGNORE_KEYWORDS
-        path = path or self.getPathInTempStore(key)
+        path = os.path.abspath(path) if path else self.getPathInTempStore(key)
         url = self.storageUrl(key, bucketOrBucketName=bucket)
 
         if not quiet:
@@ -348,7 +348,7 @@ class Storage(base.Storage):
     ):
         bucket = self.getBucket(bucketOrBucketName)
         ignores = ignores or self.DEFAULT_IGNORE_KEYWORDS
-        path = path or self.getPathInTempStore(key)
+        path = os.path.abspath(path) if path else self.getPathInTempStore(key)
         url = self.storageUrl(key, bucketOrBucketName=bucket)
         fileSize = self.getLocalSize(path)
 
